# Summary

- [Introduction](./intro.md)
    - [Installation](./install.md)
- [Quickstart](./quickstart.md)
- [Basics](./basics/index.md)
    - [Design Principles](./basics/design.md)
- [Core References](./references/index.md)
    - [Benchmark Suite](./references/suite.md)
    - [Runtime](./references/runtime.md)
    - [Modifier](./references/modifier.md)
- [Command References](./commands/index.md)
    - [`runbms`](./commands/runbms.md)
    - [`minheap`](./commands/minheap.md)
    - [`fillin`](./commands/fillin.md)
- [Cookbook](./cookbook/index.md)
    - [Performance Event Monitoring](./cookbook/perf_events.md)
- [Frequently Asked Questions](./faq.md)
- [Changelog](./changelog.md)
